Method: Inch::Language::JavaScript::Provider::JSDoc::Object::Base#files
- Defined in:
- lib/inch/language/javascript/provider/jsdoc/object/base.rb
#files ⇒ Array<CodeLocation>
Returns all files declaring the object in the form of an Array of Arrays containing the location of their declaration.
32 33 34 35 36 37 38 |
# File 'lib/inch/language/javascript/provider/jsdoc/object/base.rb', line 32 def files return [] unless filename = ['path'] + '/' + ['filename'] [ Inch::Utils::CodeLocation.new('', filename, ['lineno']) ] end |